@@ -1,9 +1,8 @@
+import asyncio
 from collections import defaultdict
-from digitalguide.whatsapp.WhatsAppUpdate import WhatsAppUpdate
+from digitalguide.twilio.TwilioUpdate import TwilioUpdate
 import yaml
 
-import time
-
 from configparser import ConfigParser
 config = ConfigParser()
 config.read('config.ini')
@@ -21,9 +20,6 @@ def read_action_yaml(filename, action_functions={}):
 
     return actions_dict
 
-
-unsend_messages = defaultdict(set)
-
 class Action():
     def __init__(self, actions, action_functions={}, log_user=True, log_interaction=True):
         self.actions = actions
@@ -45,18 +41,18 @@ class Action():
             
 
 
-    def __call__(self, client, update: WhatsAppUpdate, context):
+    async def __call__(self, client, update: TwilioUpdate, context):
         if self.log_user and not ("user_id" in context.keys()):
-            from digitalguide.whatsapp.db_objects import WhatsappUser
-            db_user = WhatsappUser(ProfileName=update.ProfileName,
+            from digitalguide.twilio.db_objects import TwilioUser
+            db_user = TwilioUser(ProfileName=update.ProfileName,
                            WaId=update.WaId)
             db_user.save()
             context["user_id"] = db_user
 
         if self.log_interaction:
-            from digitalguide.whatsapp.db_objects import WhatsappInteraction
+            from digitalguide.twilio.db_objects import TwilioInteraction
 
-            WhatsappInteraction(user=context["user_id"],
+            TwilioInteraction(user=context["user_id"],
                             Latitude = update.Latitude,
                             Longitude = update.Longitude,
                             SmsMessageSid = update.SmsMessageSid,
@@ -85,13 +81,6 @@ class Action():
             if item["type"] == "return":
                 return item["state"]
 
-            wait_itteration = 0
-            max_wait_itteration = 30
-            while unsend_messages[update.From] and wait_itteration <= max_wait_itteration:
-                print(unsend_messages, wait_itteration)
-                time.sleep(.1)
-                wait_itteration+=1
-
             if item["type"] == "message":
                 message = client.messages.create(
                     body=item["text"].format(
@@ -99,10 +88,7 @@ class Action():
                     from_=update.To,
                     to=update.From
                 )
-                print("before add",unsend_messages)
-                unsend_messages[update.From].add(message.sid)
-                print("after add",unsend_messages)
-                print(message.sid)
+                
             elif item["type"] == "venue":
                 message = client.messages.create(
                     body=item["title"],
@@ -111,35 +97,30 @@ class Action():
                     from_=update.To,
                     to=update.From
                 )
-                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "photo":
                 message = client.messages.create(
                     media_url=item["url"],
                     from_=update.To,
                     to=update.From
                 )
-                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "video":
                 message = client.messages.create(
                     media_url=item["url"],
                     from_=update.To,
                     to=update.From
                 )
-                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "media_group":
                 message = client.messages.create(
                     media_url=item["urls"],
                     from_=update.To,
                     to=update.From
                 )
-                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "audio" or item["type"] == "voice":
                 message = client.messages.create(
                     media_url=[item["url"]],
                     from_=update.To,
                     to=update.From
                 )
-                unsend_messages[update.From].add(message.sid)
             elif item["type"] == "poll":
                 message = item["question"] + "\n"
                 for option in item["options"]:
@@ -149,7 +130,6 @@ class Action():
                     from_=update.To,
                     to=update.From
                 )
-                unsend_messages[update.From].add(message.sid)
 
             elif item["type"] == "function":
                 arguments = {i: item[i]
