@@ -164,12 +164,12 @@ class FilterRasa:
 
             token_response = req.post(
                 config["rasa"]["url"] + "/api/auth", data=payload, timeout=1)
-            logger.debug(token_response.json())
+            print(token_response.json())
 
             RASA_TOKEN = token_response.json()["access_token"]
             response = req.post(config["rasa"]["url"] + "/api/projects/default/logs", params={
                                 "q": update.Body}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout=(3, 8))
-            logger.debug(response.json())
+            print(response.json())
         except Exception as e:
             logger.debug(e)
             return False
