@@ -13,7 +13,7 @@ def whatsapp_save_value_to_context(client, update: WhatsAppUpdate, context, key,
     context[key] = value
 
 
-twilio_action_functions = {"default_name": whatsapp_default_name,
+whatsapp_action_functions = {"default_name": whatsapp_default_name,
                            "save_text_to_context": whatsapp_save_text_to_context,
                            "save_value_to_context": whatsapp_save_value_to_context
                            }
